#
# spec file for package python-Pint
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
%bcond_without  test
Name:           python-Pint
Version:        0.8.1
Release:        lp150.1.3
Summary:        Physical quantities module
License:        BSD-3-Clause
Group:          Development/Languages/Python
Url:            https://github.com/hgrecco/pint
Source:         https://files.pythonhosted.org/packages/source/P/Pint/Pint-%{version}.tar.gz
BuildRequires:  %{python_module devel}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module uncertainties}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-uncertainties
Recommends:     python-numpy
BuildArch:      noarch

%python_subpackages

%description
Pint is Python module/package to define, operate and manipulate physical
quantities, the product of a numerical value and a unit of measurement.
It allows arithmetic operations between them and conversions from and
to different units.

It is distributed with a comprehensive list of physical units, prefixes
and constants. Due to it's modular design, you to extend (or even rewrite!)
the complete list without changing the source code.

%prep
%setup -q -n Pint-%{version}

%build
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%if %{with test}
%check
%python_exec setup.py test
%endif

%files %{python_files}
%defattr(-,root,root,-)
%doc AUTHORS CHANGES LICENSE README
%{python_sitelib}/Pint-%{version}-py*.egg-info
%{python_sitelib}/pint/

%changelog
* Wed Aug 23 2017 toddrme2178@gmail.com
- Implement single-spec version
- Update to version 0.8.1
  * Add support for datetime math. (Issue #510, thanks robertd)
  * Fixed _repr_html_ in Python 2.7. (Issue #512)
  * Implemented BaseRegistry.auto_reduce_dimensions. (Issue #500, thanks robertd)
  * Fixed dimension compatibility bug introduced on Registry refactoring (Issue #523, thanks dalito)
- Update to version 0.8
  * Refactored the Registry in multiple classes for better separation of concerns and clarity.
  * Implemented support for defining multiple units per define call (one definition per line). (Issue #462)
  * In pow and ipow, allow array exponents (with len > 1) when base is dimensionless. (Issue #483)
  * Wraps now gets the canonical name of the unit when passed as string. (Issue #468)
  * NumPy exp and log keeps the type (Issue #95)
  * Implemented a function decorator to ensure that a context is active (with_context) (Issue #465)
  * Add warning when a System contains an unknown Group. (Issue #472)
  * Add conda-forge installation snippet. (Issue #485, thanks stadelmanma)
  * Properly support floor division and modulo. (Issue #474, thanks tecki)
  * Measurement Correlated variable fix. (Issue #463, thanks tadhgmister)
  * Implement degree sign handling. (Issue #449, thanks iamthad)
  * Change UndefinedUnitError to inherit from AttributeError (Issue #480, thanks jhidding)
  * Simplified travis for faster testing.
  * Fixed order units in siunitx formatting. (Issue #441)
  * Changed Systems lister to return a list instead of frozenset. (Issue #425, thanks GloriaVictis)
  * Fixed issue with negative values in to_compact() method. (Issue #443, thanks nowox)
  * Improved defintions. (Issues #448, thanks gdonval)
  * Improved Parser to support capital “E” on scientific notation. (Issue #390, thanks javenoneal)
  * Make sure that prefixed units are defined on the registry when unplicking. (Issue #405)
  * Automatic unit names translation through babel. (Issue #338, thanks alexbodn)
  * Support pickling Unit objects. (Issue #349)
  * Add support for wavenumber/kayser in spectroscopy context. (Issue #321, thanks gerritholl)
  * Improved formatting. (thanks endolith and others)
  * Add support for inline comments in definitions file. (Issue #366)
  * Implement Unit.__deepcopy__. (Issue #357, thanks noahl)
  * Allow changing shape for Quantities with numpy arrays. (Issue #344, thanks tecki)
* Fri Jun  3 2016 tbechtold@suse.com
- update to 0.7.2:
  - Fixed backward incompatibility problem when parsing dimensionless units.
  - Use NIST as source for most of the unit information.
  - Added message to assertQuantityEqual.
  - Added detection of circular dependencies in definitions.
  - Added Systems and groups.
  - Implemented references for wraps decorator.
  - Added check decorator to UnitRegistry.
  - Added compact conversion.
  - Added compact formating code.
  - New Unit Class.
  - Refactor UnitRegistry.
  - Move definitions, errors, and converters into their own modules.
  - UnitsContainer is now immutable
  - New parser and evaluator.
  - Added support for Unicode identifiers.
  - Added m_as as way top retrieve the magnitude in different units.
  - Added Short form for magnitude and units.
  - Improved deepcopy.
  - Improved testing infrastructure.
  - Improved docs.
  - Fixed short names on electron_volt and hartree.
  - Fixed definitions of scruple and drachm.
  - Fixed troy ounce to 480 'grains'.
  - Added 'quad' as a unit of energy (= 10**15 Btu).
  - Added "hectare" as a supported unit of area and 'ha' as the symbol for hectare.
  - Added peak sun hour and Langley.
  - Added photometric units: lumen & lux.
  - A fraction magnitude quantity is conserved
  - Improved conversion performance by removing unnecessart try/except.
  - Added to_tuple and from_tuple to facilitate serialization.
  - Fixed support for NumPy 1.10 due to a change in the Default casting rule
  - Infrastructure: Added doctesting.
  - Infrastructure: Better way to specify exclude matrix in travis.
- Use gzip tarball instead of zip
* Tue Nov 11 2014 toddrme2178@gmail.com
- Update to 0.6
  - Fix operations with measurments and user defined units. (Issue #204)
  - Faster conversions through caching and other performance improvements. (Issue #193, thanks MatthieuDartiailh)
  - Better error messages on Quantity.__setitem__. (Issue #191)
  - Fixed abbreviation of fluid_ounce. (Issue #187, thanks hsoft)
  - Defined Angstrom symbol. (Issue #181, thanks JonasOlson)
  - Removed fetching version from git repo as it triggers XCode installation on OSX. (Issue #178, thanks deanishe)
  - Improved context documentation. (Issue #176 and 179, thanks rsking84)
  - Added Chemistry context. (Issue #179, thanks rsking84)
  - Fix help(UnitRegisty) (Issue #168)
  - Optimized "get_dimensionality" and "get_base_name". (Issue #166 and #167, thanks jbmohler)
  - Renamed ureg.parse_units parameter "to_delta" to "as_delta" to make clear. that no conversion happens. Accordingly, the parameter/property "default_to_delta" of UnitRegistry was renamed to "default_as_delta". (Issue #158, thanks dalit)
  - Fixed problem when adding two uncertainties. (thanks dalito)
  - Full support for Offset units (e.g. temperature) (Issue #88, #143, #147 and #161, thanks dalito)
* Mon Jul  7 2014 toddrme2178@gmail.com
- Update to 0.5.1
  - Implemented a standard way to change the registry used in unpickling operations. (Issue #148)
  - Fix bug where conversion would fail due to caching. (Issue #140, thanks jdreaver)
  - Allow assigning Not a Number to a quantity array. (Issue #127)
  - Decoupled Quantity in place and not in place unit conversion methods.
  - Return None in functions that modify quantities in place.
  - Improved testing infrastructure to check for unwanted warnings.
  - Added test function at the package level to run all tests.
* Thu May  8 2014 toddrme2178@gmail.com
- Update to 0.5.0
  - Improved test suite helper functions.
  - Print honors default format w/o format().
  - Fixed sum() by treating number zero as a special case.
  - Improved behaviour in ScaleConverter, OffsetConverter
    and Quantity.to.
  - Reimplemented loading of default definitions to allow Pint in
    a cx_freeze or similar package.
  - Implemented parsing of pretty printed units.
  - Fixed representation of dimensionless quantities.
  - Raise error when invalid formatting code is given.
  - Default registry to lazy load, raise error on redefinition.
  - Added condensed format.
  - Added UnitRegistry () operator to parse
    expression replacing [].
  - Optional case insensitive unit parsing.
  - Change the Quantity mutability depending on magnitude type.
  - Implemented API to list compatible units.
  - Implemented cache of key UnitRegistry methods.
  - Rewrote the Measurement class to use uncertainties.
* Thu Mar 27 2014 toddrme2178@gmail.com
- Update to 0.4.2
  - Python 2.6 support
  - Fixed symbol for inch.
  - Stop raising AttributeError when wrapping funcs without all of the attributes.
  - Fixed warning appearing in Py2.x when comparing a Numpy Array with an empty string.
  - Add links to AUR packages in docs.
  - Fixed garbage collection related problem.
* Tue Feb  4 2014 toddrme2178@gmail.com
- Initial version (0.4.1)
